from setuptools import setup, find_packages

VERSION = '0.0.1'
DESCRIPTION = 'This package includes algorithms such as LinearSearch,BinarySearch, Two pointer , Sliding window. It will get updated every week!!!'

# Setting up
setup(
    name="trialrumour",
    version=VERSION,
    author="Rumour(Sarthak Samantaray)",
    author_email="<sarthak.samantaraycoding@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    packages=[''],
    install_requires = [])